@@ -1,5 +1,5 @@
 /*
- MRTG 2.9.12a  -- Rateup
+ MRTG 2.9.14  -- Rateup
  *********************
 
  Rateup is a fast add-on to the great MRTG Traffic monitor.  It makes
@@ -61,7 +61,7 @@
 #include <gd.h>
 #include <gdfonts.h>
 
-char *VERSION = "2.9.12a";
+char *VERSION = "2.9.14";
 char *program,*router,*routerpath;
 int histvalid;
 
